<?php
namespace Teknisa\CMP\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\Libs\Util\SMTP;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DependencyInjection\InstanceManager;

class TestConfigurationEmailcomprasController extends \Zeedhi\Framework\Controller\Report
{
    protected $birtStrategy;
    protected $reportService;
    protected $QR2Strategy;
    protected $smtpUtil;
    protected $environment;
    
    public function __construct($reportService, $birtStrategy, $QR2Strategy, $smtpUtil, $environment) {
        $this->reportService     = $reportService;
        $this->birtStrategy      = $birtStrategy;
        $this->QR2Strategy       = $QR2Strategy;
        $this->smtpUtil          = $smtpUtil;
        $this->environment       = $environment;
    }
    
    /** @var array */
    protected $reportMapping = array (
        'testConfiguration' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array ("NRORG" => "NRORG")
            ),
        'GER01300' =>
            array (
                'strategy' => 'QR2',
                'parameterMapping' =>
                    array ()
            )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();

        $qr2type = isset($row['QR2TYPE']) ? $row['QR2TYPE'] : 'PDF';
        $row['NRORG'] = $this->environment->getNrorgTrab();

        $this->birtStrategy->setReportFormat($qr2type);
        $this->QR2Strategy->setQr2Type($qr2type);
    }
    
    public function testConfiguration(DTO\Request\Row $request, DTO\Response $response) {
        
        $row = $request->getRow();
        if($row['action'] == 'sendMail') {
            try {
                self::sendMail($row);
                $response->addDataSet(new DataSet('success')); 
            } catch (\Exception $e){
                $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
            return $response;
        } else {
            parent::createRemoteReport($request, $response);
        }
        
    }
    
    public function sendMail($row) {
        
        //Mensagem padrão a ser enviada
        $message = 'TEST PHPMailer';
        
        //Valida e "monta" a array dos emails
        $EMAILFOR = str_replace(";", ",", $row['EMAILFOR']);
        $EMAILFOR = str_replace(" ", "", $EMAILFOR);
        $EMAILFOR = explode(",", $EMAILFOR);
        
        //Define o Servidor Smtp
        $SERVIDORSMTP = explode(':', $row['SERVIDORSMTP']);
        $SERVIDORSMTP = $SERVIDORSMTP[0];
        
        //Define a porta Smtp
        $PORTSMTP = strstr($row['SERVIDORSMTP'], ':');
        if(strlen($PORTSMTP) > 1) {
            $PORTSMTP = explode(':', $PORTSMTP);
            $PORTSMTP = $PORTSMTP[1];
        }
        
        //Cria uma nova instancia de configurações do Smtp
        $this->smtpUtil = new SMTP([
            'smtpAuth'      => $row['RQAUTENTICACAO'] == 'S' ? true :  ($row['RQAUTENTICACAO'] == 'N' ?  false : ''),
            'host'          => $SERVIDORSMTP,
            'username'      => $row['EMAILSMTP'],
            'port'          => $PORTSMTP,
            'smtpSecure'    => $row['PRTCLSEGURANCASMTP'] == 'TLS' ? 'TLS' :  ($row['PRTCLSEGURANCASMTP'] == 'SSL' ?  'LLS' : ''),
            'from'          => $row['LOGINSMTP'],
            'subject'       => $message
        ]);
        
        //Seta o assunto do email
        $this->smtpUtil->setSubject($message);

        //Valida o field Senha Smtp
        if(isset($row['SENHASMTP'])) {
            $this->smtpUtil->setPassword($row['SENHASMTP']);
        } else if (isset($row['SENHASMTP']) && strlen($row['SENHASMTP']) < 1) {
            $this->smtpUtil->setPassword('');
        }
        
        //Se houver email a ser enviado para cópia (seta no terceiro parametro) - senão não seta
        if(isset($row['COPYFOR'])) {
            $EMAILCOPY = str_replace(";", ",", $row['COPYFOR']);
            $EMAILCOPY = str_replace(" ", "", $EMAILCOPY);
            $EMAILCOPY = explode(",", $EMAILCOPY);
            $this->smtpUtil->sendMail($message, $EMAILFOR, $EMAILCOPY);
        } else {
            $this->smtpUtil->sendMail($message, $EMAILFOR);
        }
        
    }
    
}
