<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services\CMP03905ImportacaoSolicitacaoComprasService;

class CMP03905ImportacaoSolicitacaoComprasController extends \Teknisa\GER\Controllers\TeknisaCrud
{
    protected $crudService;
    protected $service;
    
    public function __construct($crudService, $parameterBag, CMP03905ImportacaoSolicitacaoComprasService $service)
    {
        $this->crudService = $crudService;
        $this->service = $service;
    }
    
    public function retornaItensSolicitacaoCompras(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            
            /**
             * Condição valida a quantidade de parâmetros para impedir que estoure
             * erro caso o usuário utilize o 'Pesquisar' do floatingControl sem
             * ter realizado o filtro primeiro.
             * Retorna um array vazio para forçar o "Não há registros".
             */
            if (count($conditions) < 9) {
                $dataSourceName = 'cmp03905_grid_importacao_solicitacao_compras';
                
                $solicitacoes = [];
            } else {
                $parameters = self::getParametersFromCondititions($conditions);
                
                $utilizaModProdFil = $this->service->adqUtModProd($parameters)[0]['IDUTMODPRODFIL'];
                if ($utilizaModProdFil == 'N') {
                    $dataSourceName = 'cmp03905_grid_importacao_solicitacao_compras_1';
                } else {
                    $dataSourceName = 'cmp03905_grid_importacao_solicitacao_compras';
                }
                
                $datasProcessamentoFilial = $this->service->getDataProcessamentoFilial($parameters)[0];
                
                array_push($conditions, [
                    'columnName' => 'P_DTPROC',
                    'value' =>  substr($datasProcessamentoFilial['DTPROCESSAFUT'], 0, 10),
                    'operator' => '=',
                ], [
                    'columnName' => 'P_DTPROCS',
                    'value' =>   substr($datasProcessamentoFilial['DTPROCESSA'], 0, 10),
                    'operator' => '=',
                ]);
                
                $solicitacoes = $this->crudService->getFilteredDataSet($dataSourceName, $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();
                
                if (!empty($parameters['P_LISTAPRECO'])) {
                    if (!empty($solicitacoes)) {
                        $stModulo = 'SUP';
                        
                        foreach ($solicitacoes as $solicitacao) {
                            $paramsAdqListaPreco = [
                                'P_CDCENTCMP'   => $parameters['P_CDCENTCMP'],
                                'P_CDFORNECED'  => $parameters['P_CDFORNECED'],
                                'P_CDFILDEST'   => $parameters['P_CDFILIAL'],
                                'P_DTPROGENTAF' => $solicitacao['DTPROGENTR'],
                                'P_CDPRODUTO'   => $solicitacao['CDPRODUTO'],
                                'P_SISTEMA'     => $stModulo,
                            ];
                        
                            $listaPreco = $this->service->adqListaPreco();
                            
                            if (!empty($listaPreco)) {
                                $firstListaPreco = $listaPreco[0];
                                if (!empty($firstListaPreco['VRCUSTO'])) {
                                    $solicitacao['VRCUSTO'] = $firstListaPreco['VRCUSTO'];
                                }
                            }
                        }
                    }
                }
            }
        
            $response->addDataSet(new DataSet($dataSourceName, $solicitacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function retornaSolicitacoesCompras(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            
            $conditions = $request->getFilterCriteria()->getConditions();
            $parameters = self::getParametersFromCondititions($conditions);
            
            $utilizaModProdFil = $this->service->adqUtModProd($parameters)[0]['IDUTMODPRODFIL'];
            
            if ($utilizaModProdFil == 'N') {
                $dataSourceName = 'cmp03905_solicitacoes_compras_1';
            } else {
                $dataSourceName = 'cmp03905_solicitacoes_compras';
            }
            
            $solicitacoes = $this->crudService->getFilteredDataSet($dataSourceName, $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();
            $response->addDataSet(new DataSet($dataSourceName, $solicitacoes));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function retornaProdutosFornecedor(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $request = $request->getFilterCriteria()->getConditions();
            $procedure = $this->service->retornaProdutosFornecedor($request);            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function procedureIMPORT_PRODFORNCOMP(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $request = $request->getFilterCriteria()->getConditions();
            $procedure = $this->service->procedureIMPORT_PRODFORNCOMP($request);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getParametersFromCondititions($conditions)
    {
        return array_merge(...array_map(function($param) {
        	return [ $param['columnName'] => $param['value'] ];
        }, $conditions));
    }
}
