<?php

namespace Teknisa\CMP\Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Method;
use Zeedhi\Framework\DataSource\DataSet;
use Exception;

class Cmp00600ParametrosComprasSuprimentosController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceManager;
    protected $crudService;
	protected $dataSourceNameToSave;
	protected $connection;
	
    protected $cdgrupoper;
    protected $cdfilial;
    protected $tipo;

    public function __construct($crudService,  $environment, $dataSourceManager, $connection) {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection = $connection;
    }

    public function saveFilial (DTO\Request\Row $request, DTO\Response $response){
    	$this->saveFilialData($request, $response);
    }

    public function saveGrupoOperador (DTO\Request\DataSet $request, DTO\Response $response){
    	$this->saveGrupoOper($request, $response);
    }

    public function saveFilialData ($request, $response){
        
    	try {
            $this->dataSourceNameToSave = 'parasupri';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function removeOldData($row) {
        $sql = "DELETE FROM AUTGRUPOP WHERE IDAUTGRUPOP = :TIPO AND NRAUTGRUPOP = :NRAUTGRUPOP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'TIPO'        => $row['TIPO'],
                'NRAUTGRUPOP' => substr(($row['CDFILIAL']),1,3)
            )
        );
    }
    
    private function insertNewData($row) {
        if ($row['CDGRUPOPER'] == ""){
            $this->removeOldData($row);
        }else{
            $sql = "INSERT INTO AUTGRUPOP (CDGRUPOPER,IDAUTGRUPOP,NRAUTGRUPOP) VALUES (:CDGRUPOPER, :TIPO, :NRAUTGRUPOP)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'CDGRUPOPER'  => $row['CDGRUPOPER'],
                    'TIPO'        => $row['TIPO'],
                    'NRAUTGRUPOP' => substr(($row['CDFILIAL']),1,3)
                )
            );
        }
    }
    
    public function saveGrupoOper($request,$response){
        
        try {
            $rows = $request->getDataSet()->getRows();
            foreach($rows as $row) {
                $this->removeOldData($row);
                $this->insertNewData($row);
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deletePermit($request,$response){
         try {
            $this->dataSourceName = "autgrupop";
			$request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
			$dataSet = $request->getDataSet();
			$dataSet->setDataSourceName($this->dataSourceName);
			$this->crudService->delete($response, $dataSet);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function savePermit($request,$response){
        try {
            
            $row = $request->getRow();
            $sql = "SELECT * FROM AUTGRUPOP WHERE IDAUTGRUPOP = :IDAUTGRUPOP AND CDGRUPOPER = :CDGRUPOPER";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'IDAUTGRUPOP' => $row['IDAUTGRUPOP'],
                    'CDGRUPOPER'  => $row['CDGRUPOPER']
                    
                )
            );
            $dataSet = $stmt->fetchAll();
            if(sizeof($dataSet) == 0) {
                $this->dataSourceNameToSave = 'autgrupop';
                parent::save($request,$response);
            } else {
                $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    // FUNÇÕES DA ABA "FILIAL"
    
    public function saveDiversosFilial (DTO\Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            if($row["IDTIPEMITGER"] == 3) {
                if($this->verificaClientePrincipal($row["CDFILIAL"]) == 0) {
                    $response->setError(new Error('Não há cliente principal cadastrado para a filial informada.', 500));
                }
            }
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function verificaClientePrincipal($cdfilial) {
        $sql = "SELECT IDCLIENPRIN FROM CLIENFILIAL WHERE CDFILIAL = :CDFILIAL AND IDCLIENPRIN = 'S'";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $cdfilial
            )
        );
        $dataSet = $stmt->fetchAll();
        return sizeof($dataSet);
    }
    
    public function newFilialParasupri(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parasupri';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function newFilialParcmpsup(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getCdgrupprodFilial(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $sql = "SELECT
                  CDGRUPPROD
                FROM PARASUPRI
                WHERE CDFILIAL = (SELECT
                    NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AS CDFILCENTCMP
                  FROM FILIAL FILCENT,
                       FILIAL
                  WHERE FILIAL.CDFILIAL = :CDFILIAL
                  AND NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = FILCENT.CDFILIAL)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $row["CDFILIAL"]
            )
        );
        $dataSet = $stmt->fetchAll();
        if(sizeof($dataSet) == 0) {
            $cdgrupprod = null;
        } else {
            $cdgrupprod = $dataSet[0]["CDGRUPPROD"];
        }
        
        $cdgrupprod = array($cdgrupprod);
        $response->addDataSet(new DataSet ('cdgrupprod', $cdgrupprod));
    }
    
    public function getSubGrupoGeral(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $sql = "SELECT COUNT(*) AS QUANT
                FROM
                    (SELECT F.CDFILIAL
                     FROM FILIAL F
                     WHERE CDFILCENTCMP = :CDFILIAL
                         AND EXISTS
                             (SELECT P.CDGRUPPROD,
                                     P.CDSUBGRPROD
                              FROM PARCMPSUP P
                              WHERE P.CDFILIAL = F.CDFILIAL
                                  AND P.CDSUBGRPROD IS NOT NULL)
                     GROUP BY F.CDFILIAL
                     UNION SELECT F.CDFILIAL
                     FROM FILIAL F
                     WHERE CDFILIAL = :CDFILIAL
                         AND EXISTS
                             (SELECT P.CDGRUPPROD,
                                     P.CDSUBGRPROD
                              FROM PARCMPSUP P
                              WHERE P.CDFILIAL = F.CDFILIAL
                                  AND P.CDSUBGRPROD IS NOT NULL)
                     GROUP BY F.CDFILIAL)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $row["CDFILIAL"]
            )
        );
        $dataSet = $stmt->fetchAll();
        if(sizeof($dataSet) == 0) {
            $quant = 0;
        } else {
            $quant = $dataSet[0]["QUANT"];
        }
        $quant = array($quant);
        $response->addDataSet(new DataSet ('subGrupoGeral', $quant));
    }
    
    public function saveListaPrecoFilial(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
}
