/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: CALC_DATA_ENTR_MES                                                   */
/*                                                                            */
/* Descrio:                                                                 */
/* Calcula datas de entrega para um determinado mes baseando-se na            */
/* Periodicidade de Entrega e nos Feriados de Compras.                        */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/* 12/01/99 - Yoris L. de Souza                                               */
/*                                                                            */
/* Manutenes:                                                               */
/* 24/06/99 - Yoris L. de Souza - Retirei logica que mantinha data apos       */
/*            recalculo do calendario                                         */
/* 24/11/99 - Yoris L. de Souza                                               */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* PARAMETROS:                                                                */
/*                                                                            */
/* P_CDFILIAL     - Cdigo da Filial                                          */
/* P_CDPERIENTR   - Cdigo da Periodicidade de Entrega                        */
/* P_DTINICIAL    - Data do Inicio do Mes                                     */
/* P_NRMESES      - Numero de meses a serem calculados                        */
/******************************************************************************/
/* @C:\SISTEMAS\DBA\SQL\ORACLE\8050_CMPSTP_CALC_DATA_ENTR_MES.SQL  */
/* @H:\SISTEMAS\DBA\SQL\ORACLE\8050_CMPSTP_CALC_DATA_ENTR_MES.SQL  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE SF_CALC_DATA_ENTR_MES
  (P_CDFILIAL     IN VARCHAR2,
   P_CDPERIENTR   IN VARCHAR2,
   P_DTINICIAL    IN DATE,
   P_NRMESES      IN NUMBER,
   P_DTPROCESSA   IN DATE,
   P_NRORG        IN CALECOMP.NRORG%TYPE DEFAULT 1) IS
   V_CONTAMES     NUMBER;
   V_IDTIPODIA    VARCHAR2(1);
   V_IDDIANUTIL   VARCHAR2(1);
   V_DTINIAUX     DATE;
   V_DTENTREGA    DATE;
   V_DTANTPROX    DATE;
   V_CONTA        NUMBER;
   V_ENTREGA      DATE;
   V_DTANTPROXENT DATE;
BEGIN
  SELECT IDTIPODIA,IDDIANUTIL INTO V_IDTIPODIA, V_IDDIANUTIL
  FROM PERIENTR
  WHERE
  CDPERIENTR = P_CDPERIENTR;
  V_DTINIAUX := P_DTINICIAL;

  IF V_IDTIPODIA = 'R' THEN
     SEMANAL_RECORRENTE_DTENTR(P_CDFILIAL,
                               P_CDPERIENTR,
                               TO_DATE('01/'||'01/'||TO_CHAR(P_DTINICIAL, 'YYYY'), 'DD/MM/YYYY'),
                               12,
                               P_DTPROCESSA);
  ELSE
     FOR V_CONTAMES IN 1..P_NRMESES LOOP

       V_CONTA := 1;
       SELECT COUNT(*) INTO V_CONTA
       FROM CALECOMP
       WHERE
          CDFILIAL                = P_CDFILIAL   AND
          CDPERIENTR              = P_CDPERIENTR AND
          TO_CHAR(DTENTREGA,'MMYYYY') = TO_CHAR(V_DTINIAUX,'MMYYYY');

       IF V_CONTA > 0 THEN
          DELETE FROM CALECOMP
          WHERE
            CDFILIAL                = P_CDFILIAL   AND
            CDPERIENTR              = P_CDPERIENTR AND
            DTENTREGA              >= P_DTPROCESSA AND
            TO_CHAR(DTENTREGA,'MMYYYY') = TO_CHAR(V_DTINIAUX,'MMYYYY');
       END IF;

       IF V_IDTIPODIA = 'M' THEN
          MENSAL_DATA_ENTR_MES(P_CDFILIAL,P_CDPERIENTR,V_DTINIAUX,V_IDDIANUTIL,P_DTPROCESSA);
          COMMIT;
       ELSE
          IF V_IDTIPODIA = 'S' THEN
             SEMANAL_DATA_ENTR_MES(P_CDFILIAL,P_CDPERIENTR,V_DTINIAUX,V_IDDIANUTIL,P_DTPROCESSA);
             COMMIT;
          END IF;
       END IF;

       V_DTINIAUX := LAST_DAY(V_DTINIAUX) + 1;
     END LOOP;

     V_ENTREGA := NULL;
     FOR C_CALECOMP IN
       (SELECT
          DTENTREGA
        FROM
          CALECOMP
        WHERE
          CDFILIAL   = P_CDFILIAL   AND
          CDPERIENTR = P_CDPERIENTR AND
          DTENTREGA  >= ADD_MONTHS(P_DTINICIAL, -1) AND
          DTENTREGA < V_DTINIAUX
        ORDER BY
          DTENTREGA)
     LOOP
        IF V_ENTREGA IS NOT NULL THEN
           UPDATE
             CALECOMP
           SET
             DTANTPROXENT = C_CALECOMP.DTENTREGA - 1
           WHERE
             CDFILIAL   = P_CDFILIAL   AND
             CDPERIENTR = P_CDPERIENTR AND
             DTENTREGA  = V_ENTREGA;

           COMMIT;
        END IF;
        V_ENTREGA := C_CALECOMP.DTENTREGA;
     END LOOP;

     SELECT TO_DATE(MIN(DTENTREGA)-1)
       INTO V_DTANTPROXENT
       FROM CALECOMP
      WHERE CDFILIAL   = P_CDFILIAL
        AND CDPERIENTR = P_CDPERIENTR
        AND DTENTREGA  > V_ENTREGA;

     IF V_DTANTPROXENT IS NOT NULL THEN
        UPDATE
          CALECOMP
        SET
          DTANTPROXENT = V_DTANTPROXENT
        WHERE
          CDFILIAL   = P_CDFILIAL   AND
          CDPERIENTR = P_CDPERIENTR AND
          DTENTREGA  = V_ENTREGA;
     END IF;
  END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('CALC_DATA_ENTR_MES','5.05.021'); END;
/

